<?php
$lang['none'] = 'Geen';
$lang['ssl'] = 'SSL ';
$lang['tls'] = 'TLS ';
$lang['secure'] = 'Encryptie mechanisme';
$lang['info_secure'] = 'Alleen toepasbaar in de SMTP mailer methode, deze optie benoemt het te gebruiken encryptie mechanisme voor de verbinding';
$lang['info_cmsmailer'] = 'Deze module wordt door verschillende modules gebruikt voor het verzenden van E-mail.<br />Gebruik de informatie van host om de instellingen goed te zetten.<br />Wanneer het verzenden van een test bericht niet lukt, zou u hulp kunnen vragen bij uw host.';
$lang['charset'] = 'Karakterset';
$lang['sendtestmailconfirm'] = 'Dit verstuurt een test bericht naar het opgegeven adres. Als het versturen succesvol verloopt, komt u weer op deze pagina terecht. Wilt u doorgaan?';
$lang['settingsconfirm'] = 'Huidige waarden wegschrijven naar de CMSMailer instellingen?';
$lang['testsubject'] = 'CMSMailer Testbericht';
$lang['testbody'] = 'Dit bericht is alleen bedoeld om te controleren of de CMSMailer-module goed is ingesteld. Als het bericht ontvangen wordt, werkt alles naar behoren.';
$lang['error_notestaddress'] = 'Fout: geen testadres opgegeven';
$lang['prompt_testaddress'] = 'Test E-mailadres';
$lang['sendtest'] = 'Verstuur testbericht';
$lang['password'] = 'Wachtwoord';
$lang['username'] = 'Gebruikersnaam';
$lang['smtpauth'] = 'SMTP Authenticatie';
$lang['mailer'] = 'Mail-methode';
$lang['host'] = 'SMTP host name<br/><i>(of IP adres)</i>';
$lang['port'] = 'SMTP server-poortnummer';
$lang['from'] = 'Van adres';
$lang['fromuser'] = 'Van gebruikersnaam';
$lang['sendmail'] = 'Locatie van sendmail';
$lang['timeout'] = 'timeout SMTP  ';
$lang['submit'] = 'Verstuur';
$lang['cancel'] = 'Annuleer';
$lang['info_mailer'] = 'Toe te passen mail-methode (sendmail, smtp, mail). Meestal is smtp het meest betrouwbaar.';
$lang['info_host'] = 'SMTP hostname (alleen geldig voor de smtp mail-methode)';
$lang['info_port'] = 'SMTP poortnummer (meestal 25) (alleen geldig voor de smtp mail-methode)';
$lang['info_from'] = 'Adres dat gebruikt wordt als afzender in alle berichten. <br/><strong>Opmerking</strong>, dit email adres moet correct worden ingesteld voor uw website host, want anders kunnen er problemen ontstaan tijdens het verzenden van email.<br/>Als u de juiste instellingen niet weet, neemt u dan contact op met uw website host.';
$lang['info_fromuser'] = 'Naam afzender die gebruikt wordt voor het versturen van alle berichten';
$lang['info_sendmail'] = 'Het volledige pad naar de sendmail executable (alleen geldig voor de sendmail mail-methode)';
$lang['info_timeout'] = 'Het aantal seconden in een SMTP conversatie voordat een fout optreedt (geldig voor de smtp mailer-methode)';
$lang['info_smtpauth'] = 'Is voor uw smtp serverauthenticatie nodig (alleen geldig voor de smtp mail-methode)';
$lang['info_username'] = 'SMTP authenticatie gebruikersnaam (alleen geldig voor de smtp mail-methode, als smtp auth is geselecteerd)';
$lang['info_password'] = 'SMTP authenticatiewachtwoord (alleen geldig voor de smtp mail-methode, als smtp auth is geselecteerd)';
$lang['friendlyname'] = 'CMSMailer ';
$lang['postinstall'] = 'CMSMailer-module is ge&iuml;nstalleerd';
$lang['postuninstall'] = 'CMSMailer-module gede&iuml;nstalleerd';
$lang['uninstalled'] = 'Module gede&iuml;nstalleerd.';
$lang['installed'] = 'Module versie %s ge&iuml;nstalleerd.';
$lang['accessdenied'] = 'Toegang geweigerd. Zorg dat u beschikt over voldoende rechten.';
$lang['error'] = 'Fout!';
$lang['upgraded'] = 'Module bijgewerkt naar versie %s.';
$lang['title_mod_prefs'] = 'Modulevoorkeuren';
$lang['title_mod_admin'] = 'Modulebeheerpaneel';
$lang['title_admin_panel'] = 'CMSMailer-module';
$lang['moddescription'] = 'Dit is een simpele &quot;wrapper&quot; rond PHPMailer, het heeft een gelijke API (functie voor functie) en een simpele interface voor een aantal standaardwaarden.';
$lang['welcome_text'] = '<p>Welkom bij de CMSMailer-modulebeheersectie';
$lang['changelog'] = '<ul>
<li>Version 1.73.1. October, 2005. Initial Release.</li>
<li>Version 1.73.2. October, 2005. Minor bug fix with the admin panel.  The dropdown was not representing the current value from the preferences database</li>
<li>Version 1.73.3. October, 2005. Minor bug fix with sending html email</li>
<li>Version 1.73.4. November, 2005. Form fields in preferences are larger, fixed a problem with the fromuser, and called reset within the constructor</li>
<li>Version 1.73.5. November, 2005. Added the form fields and functionality for SMTP authentication.</li>
<li>Version 1.73.6. December, 2005. Default mailer method is SMTP on install, and improved documentation, and now I clear all the attachments, and addresses, etc. on reset.</li>
<li>Version 1.73.7. January, 2006. Increased field lengths in most fields</li>
<li>Version 1.73.8. January, 2006. Changed the preferences panel to be a bit more descriptive.</li>
<li>Version 1.73.9. January, 2006. Added test email capability, and confirmation on each button (except cancel)</li>
</ul>
li>Version 1.73.10. August, 2006. Modified to use lazy loading to minimize memory footprint when CMSMailer is not being used.</li>
<li>Version 1.73.13. January, 2008.  Added more permissions checks.</li>
</ul>';
$lang['help'] = '<h3>Wat doet het?</h3>
<p>Deze module bevat geen eindgebruikersfunctionaliteit. Het is ontworpen om ge&iuml;ntegreerd te worden in andere modules om emailmogelijkheden te verschaffen. </p>
<h3>Hoe gebruik ik het?</h3>
<p>Deze module geeft een eenvoudige wrapper rond alle methoden en variabelen van phpmailer.  Het is ontworpen voor gebruik door andere moduleontwikkelaars. Hieronder staat een voorbeeld en een beknopte API referentie. Lees de PHPMailer documentatie voor meer informatie.</p>
<h3>Een voorbeeld</h3>
<pre>
  $cmsmailer = $this->GetModuleInstance(&#039;CMSMailer&#039;);
  $cmsmailer->AddAddress(&#039;calguy1000@hotmail.com&#039;,&#039;calguy&#039;);
  $cmsmailer->SetBody(&#039;Dit is een testbericht&#039;);
  $cmsmailer->IsHTML(true);
  $cmsmailer->SetSubject(&#039;Test message&#039;);
  $cmsmailer->Send();
</pre>
<h3>API</h3>
<ul>
<li><p><b>void reset()</b></p>
<p>Reset the object back to the values specified in the admin panel</p>
</li>
<li><p><b>string GetAltBody()</b></p>
<p>Return the alternate body of the email</p>
</li>
<li><p><b>void SetAltBody( $string )</b></p>
<p>Set the alternate body of the email</p>
</li>
<li><p><b>string GetBody()</b></p>
<p>Return the primary body of the email</p>
</li>
<li><p><b>void SetBody( $string )</b></p>
<p>Set the primary body of the email</p>
</li>
<li><p><b>string GetCharSet()</b></p>
<p>Default: iso-8859-1</p>
<p>Return the mailer character set</p>
</li>
<li><p><b>void SetCharSet( $string )</b></p>
<p>Set the mailer character set</p>
</li>
<li><p><b>string GetConfirmReadingTo()</b></p>
<p>Return the address confirmed reading email flag</p>
</li>
<li><p><b>void SetConfirmReadingTo( $address )</b></p>
<p>Set or unset the confirm reading address</p>
</li>
<li><p><b>string GetContentType()</b></p>
<p>Default: text/plain</p>
<p>Return the content type</p>
</li>
<li><p><b>void SetContentType()</b></p>
<p>Set the content type</p>
</li>
<li><p><b>string GetEncoding()</b></p>
<p>Return the encoding</p>
</li>
<li><p><b>void SetEncoding( $encoding )</b></p>
<p>Set the encoding</p>
<p>Options are: 8bit, 7bit, binary, base64, quoted-printable</p>
</li>
<li><p><b>string GetErrorInfo()</b></p>
<p>Return any error information</p>
</li>
<li><p><b>string GetFrom()</b></p>
<p>Return the current originating address</p>
</li>
<li><p><b>void SetFrom( $address )</b></p>
<p>Set the originating address</p>
</li>
<li><p><b>string GetFromName()</b></p>
<p>Return the current originating name</p>
</li>
<li><p><b>SetFromName( $name )</b></p>
<p>Set the originating name</p>
</li>
<li><p><b>string GetHelo()</b></p>
<p>Return the HELO string</p>
</li>
<li><p><b>SetHelo( $string )</b></p>
<p>Set the HELO string</p>
<p>Default value: $hostname</p>
</li>
<li><p><b>string GetHost()</b></p>
<p>Return the SMTPs host separated by semicolon</p>
</li>
<li><p><b>void SetHost( $string )</b></p>
<p>Set the hosts</p>
</li>
<li><p><b>string GetHostName()</b></p>
<p>Return the hostname used for SMTP Helo</p>
</li>
<li><p><b>void SetHostName( $hostname )</b></p>
<p>Set the hostname used for SMTP Helo</p>
</li>
<li><p><b>string GetMailer()</b></p>
<p>Return the mailer</p>
</li>
<li><p><b>void SetMailer( $mailer )</b></p>
<p>Set the mailer, either sendmail,mail, or smtp</p>
</li>
<li><p><b>string GetPassword()</b></p>
<p>Return the password for smtp auth</p>
</li>
<li><p><b>void SetPassword( $string )</b></p>
<p>Set the password for smtp auth</p>
</li>
<li><p><b>int GetPort()</b></p>
<p>Return the port number for smtp connections</p>
</li>
<li><p><b>void SetPort( $int )</b></p>
<p>Set the port for smtp connections</p>
</li>
<li><p><b>int GetPriority()</b></p>
<p>Return the message priority</p>
</li>
<li><p><b>void SetPriority( int )</b></p>
<p>Set the message priority</p>
<p>Values are 1=High, 3 = Normal, 5 = Low</p>
</li>
<li><p><b>string GetSender()</b></p>
<p>Return the sender email (return path) string</p>
</li>
<li><p><b>void SetSender( $address )</b></p>
<p>Set the sender string</p>
</li>
<li><p><b>string GetSendmail()</b></p>
<p>Return the sendmail path</p>
</li>
<li><p><b>void SetSendmail( $path )</b></p>
<p>Set the sendmail path</p>
</li>
<li><p><b>bool GetSMTPAuth()</b></p>
<p>Return the current value of the smtp auth flag</p>
</li>
<li><p><b>SetSMTPAuth( $bool )</b></p>
<p>Set the smtp auth flag</p>
</li>
<li><p><b>bool GetSMTPDebug()</b></p>
<p>Return the value of the SMTP debug flag</p>
</li>
<li><p><b>void SetSMTPDebug( $bool )</b></p>
<p>Set the SMTP debug flag</p>
</li>
<li><p><b>bool GetSMTPKeepAlive()</b></p>
<p>Return the value of the SMTP keep alive flag</p>
</li>
<li><p><b>SetSMTPKeepAlive( $bool )</b></p>
<p>Set the SMTP keep alive flag</p>
</li>
<li><p><b>string GetSubject()</b></p>
<p>Return the current subject string</p>
</li>
<li><p><b>void SetSubject( $string )</b></p>
<p>Set the subject string</p>
</li>
<li><p><b>int GetTimeout()</b></p>
<p>Return the timeout value</p>
</li>
<li><p><b>void SetTimeout( $seconds )</b></p>
<p>Set the timeout value</p>
</li>
<li><p><b>string GetUsername()</b></p>
<p>Return the smtp auth username</p>
</li>
<li><p><b>void SetUsername( $string )</b></p>
<p>Set the smtp auth username</p>
</li>
<li><p><b>int GetWordWrap()</b></p>
<p>Return the wordwrap value</p>
</li>
<li><p><b>void SetWordWrap( $int )</b></p>
<p>Return the wordwrap value</p>
</li>
<li><p><b>AddAddress( $address, $name = &#039;&#039; )</b></p>
<p>Add a destination address</p>
</li>
<li><p><b>AddAttachment( $path, $name = &#039;&#039;, $encoding = &#039;base64&#039;, $type = &#039;application/octent-stream&#039; )</b></p>
<p>Add a file attachment</p>
</li>
<li><p><b>AddBCC( $address, $name = &#039;&#039; )</b></p>
<p>Add a BCC&#039;d destination address</p>
</li>
<li><p><b>AddCC( $address, $name = &#039;&#039; )</b></p>
<p>Add a CC&#039;d destination address</p>
</li>
<li><p><b>AddCustomHeader( $txt )</b></p>
<p>Add a custom header to the email</p>
</li>
<li><p><b>AddEmbeddedImage( $path, $cid, $name = &#039;&#039;, $encoding = &#039;base64&#039;, $type = &#039;application/octent-stream&#039; )</b></p>
<p>Add an embedded image</p>
</li>
<li><p><b>AddReplyTo( $address, $name = &#039;&#039; )</b></p>
<p>Add a reply to address</p>
</li>
<li><p><b>AddStringAttachment( $string, $filename, $encoding = &#039;base64&#039;, $type = &#039;application/octent-stream&#039; )</b></p>
<p>Add a file attachment</p>
</li>
<li><p><b>ClearAddresses()</b></p>
<p>Clear all addresses</p>
</li>
<li><p><b>ClearAllRecipients()</b></p>
<p>Clear all recipients</p>
</li>
<li><p><b>ClearAttachments()</b></p>
<p>Clear all attachments</p>
</li>
<li><p><b>ClearBCCs()</b></p>
<p>Clear all BCC addresses</p>
</li>
<li><p><b>ClearCCs()</b></p>
<p>Clear all CC addresses</p>
</li>
<li><p><b>ClearCustomHeaders()</b></p>
<p>Clear all custom headers</p>
</li>
<li><p><b>ClearReplyto()</b></p>
<p>Clear reply to address</p>
</li>
<li><p><b>IsError()</b></p>
<p>Check for an error condition</p>
</li>
<li><p><b>bool IsHTML( $bool )</b></p>
<p>Set the html flag</p>
<p><i>Note</i> possibly this should be a get and set method</p>
</li>
<li><p><b>bool IsMail()</b></p>
<p>Check wether we are using mail</p>
</li>
<li><p><b>bool IsQmail()</b></p>
<p>Check wether we are using qmail</p>
</li>
<li><p><b>IsSendmail()</b></p>
<p>Check wether we are using sendmail</p>
</li>
<li><p><b>IsSMTP()</b></p>
<p>Check wether we are using smtp</p>
</li>
<li><p><b>Send()</b></p>
<p>Send the currently prepared email</p>
</li>
<li><p><b>SetLanguage( $lang_type, $lang_path = &#039;&#039; )</b></p>
<p>Set the current language and <em>(optional)</em> language path</p>
</li>
<li><p><b>SmtpClose()</b></p>
<p>Close the smtp connection</p>
</li>
</ul>
<h3>Support</h3>
<p>This module does not include commercial support. However, there are a number of resources available to help you with it:</p>
<ul>
<li>For the latest version of this module, FAQs, or to file a Bug Report or buy commercial support, please visit calguys homepage at <a href=&#039;http://techcom.dyndns.org&#039;>techcom.dyndns.org</a>.</li>
<li>Additional discussion of this module may also be found in the <a href=&#039;http://forum.cmsmadesimple.org&#039;>CMS Made Simple Forums</a>.</li>
<li>The author, calguy1000, can often be found in the <a href=&#039;irc://irc.freenode.net/#cms&#039;>CMS IRC Channel</a>.</li>
<li>Lastly, you may have some success emailing the author directly.</li>  
</ul>
<p>As per the GPL, this software is provided as-is. Please read the text
of the license for the full disclaimer.</p>

<h3>Copyright and License</h3>
<p>Copyright &amp;copy; 2005, Robert Campbell <a href=&#039;mailto:calguy1000@hotmail.com&#039;>&amp;lt;calguy1000@hotmail.com&amp;gt;</a>. All Rights Are Reserved.</p>
<p>This module has been released under the <a href=&#039;http://www.gnu.org/licenses/licenses.html#GPL&#039;>GNU Public License</a>. You must agree to this license before using the module.</p>';
$lang['utma'] = '156861353.295485234.1263563671.1272313485.1272349454.280';
$lang['utmz'] = '156861353.1272029290.265.10.utmcsr=forum.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/index.php/topic,18827.0.html';
$lang['qca'] = 'P0-1209344414-1263563671334';
$lang['utmb'] = '156861353.1.10.1272349454';
$lang['utmc'] = '156861353';
?>